pub struct JsonSchemaValidatingEncoder { /* private fields */ }Expand description
An encoder that validates an Attestation’s optional payload field
against a provided JSON schema before serializing the entire Attestation.
Implementations
Sourceimpl JsonSchemaValidatingEncoder
impl JsonSchemaValidatingEncoder
Sourcepub fn new(schema_value: Value) -> Self
pub fn new(schema_value: Value) -> Self
Creates a new validating encoder which will use the provided schema.
Sourcepub fn encode(&self, att: &Attestation) -> Result<Vec<u8>, StorageError>
pub fn encode(&self, att: &Attestation) -> Result<Vec<u8>, StorageError>
Validates the att.payload against the stored schema (if payload exists)
and then serializes the entire att struct to pretty JSON bytes.
Returns Err if schema validation fails for an existing payload, or if
final JSON serialization fails.